# -*- coding: utf-8 -*-

import logging as log
import requests
import hashlib


def invoke(url, username, password, accesskey, action, format, parameters):
    content_type = "application/%s" % format
    headers = {'content-type': content_type}

    payload = {
        'username': username,
        'password': hashlib.md5(password).hexdigest(),
        'accesskey': accesskey,
        'responsetype': format,
        'action': action}
    payload.update(parameters)
    log.debug("PAYLOAD: %s" % payload)

    r = requests.post(url, data=payload)
    print "%s" % r.text
    return (r.status_code, r.text)



# -*- coding: utf-8 -*-

import argparse
import logging as log
from whmcs import invoke


def main():
    parser = argparse.ArgumentParser(
        description="pyWHMCS Client Command Line Interface")
    parser.add_argument("--verbose",
                        action="store_true",
                        help="Activate verbose output")
    parser.add_argument("--url", help="WHMCS API endpoint URL", required=True)
    parser.add_argument("--username",
                        help="Username with API permission",
                        required=True)
    parser.add_argument("--password", help="API user password", required=True)
    parser.add_argument("--accesskey", help="API Access Key", required=True)
    parser.add_argument("--action", help="Action to invoke", required=True)
    parser.add_argument(
        "--params",
        nargs=argparse.REMAINDER,
        help="Parameters for with action.(param1=value1 param2=value2 etc.)")
    parser.add_argument("--format",
                        help="Response format",
                        choices=['json', 'xml'],
                        default="json")
    args = parser.parse_args()

    if args.verbose:
        log.basicConfig(level=log.DEBUG)
    log.basicConfig(level=log.WARNING)

    log.info("Parameter List:")

    for k, v in args.__dict__.items():
        log.info("%s = %s" % (k.upper(), v))

    params_dict = {}
    if args.params:
        for p in args.params:
            p_list = p.split('=')
            if len(p_list) != 2 or p_list[0] == "" or p_list[1] == "":
                log.info("Bad formatted --params: %s" % args.params)
                parser.error("Params bad format. Each param must be in param1=\
                    value1 format. Your data: %s" % p)
            params_dict[p_list[0]] = p_list[1]
        log.info("PARAMS dictionary: %s" % params_dict)

    invoke(args.url,
           args.username,
           args.password,
           args.accesskey,
           args.action,
           args.format,
           params_dict)

if __name__ == '__main__':
    main()



from setuptools import setup, find_packages
import sys
import os

here = os.path.abspath(os.path.dirname(__file__))
README = open(os.path.join(here, 'README.rst')).read()
NEWS = open(os.path.join(here, 'NEWS.txt')).read()


version = '0.0.3'

install_requires = [
    'requests',
]


setup(
    name='pywhmcs7',
    version=version,
    description="WHMCS Client Library",
    long_description=README + '\n\n' + NEWS,
    classifiers=[
        "Development Status :: 1 - Planning",
        "Development Status :: 2 - Pre-Alpha",
        "Environment :: Console",
        "Intended Audience :: Developers",
        "Intended Audience :: System Administrators",
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
        "Natural Language :: English",
        "Operating System :: Microsoft :: Windows",
        "Operating System :: POSIX :: Linux",
        "Programming Language :: Python :: 2.7",
        "Topic :: Internet :: WWW/HTTP",
    ],
    keywords='whmcs library http api',
    author='Zekeriya Koc and Rizal',
    author_email='riesal@gmail.com',
    url='https://github.com/riesal/pywhmcs7',
    license='Gnu General Public License v3',
    packages=find_packages('src'),
    package_dir={'': 'src'}, include_package_data=True,
    zip_safe=False,
    install_requires=install_requires,
    entry_points={
        'console_scripts':
            ['pywhmcs7=pywhmcs7:main']
    }
)
